from lium.cli.actions import ActionResult
from lium.cli.settings import config


class GetConfigAction:
    """Get config value."""

    def execute(self, ctx: dict) -> ActionResult:
        """Execute config get."""
        key: str = ctx["key"]

        value = config.get(key)

        if value is None:
            return ActionResult(ok=False, error=f"Key '{key}' not found")

        return ActionResult(ok=True, data={"value": value})



"""Up command validation."""


def validate(executor_id: str | None, gpu: str | None, count: int | None, country: str | None, ttl: str | None, until: str | None) -> tuple[bool, str]:
    """Validate up command inputs."""
    if executor_id and (gpu or count or country):
        return False, "Cannot use filters (--gpu, --count, --country) when specifying an executor ID"

    if not executor_id and not (gpu or count or country):
        return False, "Must provide either EXECUTOR_ID or filters (--gpu, --count, --country)"

    if ttl and until:
        return False, "Cannot specify both --ttl and --until"

    return True, ""
